@@ -22,10 +22,10 @@
  *
  * HUBzero is a registered trademark of Purdue University.
  *
- * @package   hubzero-cms
- * @author    Shawn Rice <zooley@purdue.edu>
+ * @package		hubzero-cms
+ * @author		Shawn Rice <zooley@purdue.edu>
  * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
- * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
+ * @license		http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  */
 
 // Check to ensure this file is included in Joomla!
@@ -39,7 +39,7 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 	/**
 	 * List citations
 	 *
-	 * @return     void
+	 * @return		 void
 	 */
 	public function displayTask()
 	{
@@ -50,13 +50,13 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 		$this->view->filters = array();
 
 		// Get paging variables
-		$this->view->filters['limit']    = $app->getUserStateFromRequest(
+		$this->view->filters['limit']	 = $app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.limit',
 			'limit',
 			$config->getValue('config.list_limit'),
 			'int'
 		);
-		$this->view->filters['start']    = $app->getUserStateFromRequest(
+		$this->view->filters['start']	 = $app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.limitstart',
 			'limitstart',
 			0,
@@ -64,12 +64,12 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 		);
 
 		// Get filters
-		$this->view->filters['sort']     = trim($app->getUserStateFromRequest(
+		$this->view->filters['sort']	 = trim($app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.sort',
 			'sort',
 			'created DESC'
 		));
-		$this->view->filters['search']     = urldecode(trim($app->getUserStateFromRequest(
+		$this->view->filters['search']		 = urldecode(trim($app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.search',
 			'search',
 			''
@@ -114,7 +114,7 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 	/**
 	 * Create a new citation
 	 *
-	 * @return     void
+	 * @return		 void
 	 */
 	public function addTask()
 	{
@@ -124,7 +124,7 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 	/**
 	 * Edit a citation
 	 *
-	 * @return     void
+	 * @return		 void
 	 */
 	public function editTask()
 	{
@@ -300,10 +300,46 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 		);
 	}
 
+	/** 
+	* Toggle affliliation 
+	*
+	* @return void
+	*/
+	public function affiliateTask()
+	{
+	// get the id of the citation
+	$id = JRequest::getInt('id', '');
+	$row = new CitationsCitation($this->database);
+	$row->load($id);
+
+	// toggle the affiliation
+	if ($row->affiliated == 1)
+	{
+		$row->affiliated = 0;
+	}
+	elseif ($row->affiliated == 0)
+	{
+		$row->affiliated = 1;
+	}
+
+	if (!$row->save($row))
+		{
+			$this->setError($row->getError());
+			$this->displayTask();
+			return;
+		}
+
+		// Redirect
+		$this->setRedirect(
+			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
+			JText::_('CITATION_UNPUBLISHED')
+		);
+	}
+
 	/**
 	 * Display stats for citations
 	 *
-	 * @return     void
+	 * @return		 void
 	 */
 	public function statsTask()
 	{
@@ -327,7 +363,7 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 	/**
 	 * Save a citation
 	 *
-	 * @return     void
+	 * @return		 void
 	 */
 	public function saveTask()
 	{
@@ -341,6 +377,17 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 		$this->badges = trim(JRequest::getVar('badges', ''));
 		$this->sponsors = JRequest::getVar('sponsors', array(), 'post');
 
+		// for checkboxes
+		if (!isset($citation['affiliated']))
+		{
+			$citation['affiliated'] = 0;
+		}
+
+		if (!isset($citation['fundedby']))
+		{
+			$citation['fundeby'] = 0;
+		}
+
 		// Bind incoming data to object
 		$row = new CitationsCitation($this->database);
 		if (!$row->bind($citation))
@@ -450,9 +497,9 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 	/**
 	 * Check if an array has any values set other than $ignored values
 	 *
-	 * @param      array $b       Array to check
-	 * @param      array $ignored Values to ignore
-	 * @return     boolean True if empty
+	 * @param		 array $b			Array to check
+	 * @param		 array $ignored Values to ignore
+	 * @return		 boolean True if empty
 	 */
 	private function _isEmpty($b, $ignored=array())
 	{
@@ -482,7 +529,7 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 	/**
 	 * Remove one or more citations
 	 *
-	 * @return     void
+	 * @return		 void
 	 */
 	public function removeTask()
 	{
@@ -541,7 +588,7 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 	/**
 	 * Cancel a task (redirects to default task)
 	 *
-	 * @return     void
+	 * @return		 void
 	 */
 	public function cancelTask()
 	{
@@ -554,8 +601,8 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 	/**
 	 * Get the params for a citation
 	 *
-	 * @param      integer $citation Citation ID
-	 * @return     integer
+	 * @param		 integer $citation Citation ID
+	 * @return		 integer
 	 */
 	private function _getParams($citation = 0)
 	{
