@@ -46,7 +46,7 @@ class CoursesControllerLogo extends \Hubzero\Component\AdminController
 	public function ajaxUploadTask()
 	{
 		// Check for request forgeries
-		JRequest::checkToken('get') or JRequest::checkToken() or jexit('Invalid Token');
+		JRequest::checkToken(array('get', 'post')) or jexit('Invalid Token');
 
 		// Ensure we have an ID to work with
 		$id = JRequest::getInt('id', 0);
@@ -348,7 +348,7 @@ class CoursesControllerLogo extends \Hubzero\Component\AdminController
 	public function ajaxRemoveTask()
 	{
 		// Check for request forgeries
-		JRequest::checkToken('get') or JRequest::checkToken() or jexit('Invalid Token');
+		JRequest::checkToken(array('get', 'post')) or jexit('Invalid Token');
 
 		// Ensure we have an ID to work with
 		$id = JRequest::getInt('id', 0);
