@@ -152,6 +152,12 @@ class AnswersControllerQuestions extends \Hubzero\Component\SiteController
 		$questionID = JRequest::getVar('rid');
 		$comment = JRequest::getVar('comment', array(), 'post', 'none', 2);
 
+		// clean input
+		array_walk($comment, function(&$field, $key)
+		{
+			$field = \Hubzero\Utility\Sanitize::clean($field);
+		});
+
 		if (!$comment['item_id'])
 		{
 			JError::raiseError(500, JText::_('COM_ANSWERS_ERROR_QUESTION_ID_NOT_FOUND'));
@@ -841,10 +847,9 @@ class AnswersControllerQuestions extends \Hubzero\Component\SiteController
 		}
 
 		// clean input
-		array_walk($fields, function($field, $key)
+		array_walk($fields, function(&$field, $key)
 		{
-			$fields[$key] = \Hubzero\Utility\Sanitize::stripScripts($field);
-			$fields[$key] = \Hubzero\Utility\Sanitize::clean($field);
+			$field = \Hubzero\Utility\Sanitize::clean($field);
 		});
 
 		// Initiate class and bind posted items to database fields
@@ -860,6 +865,13 @@ class AnswersControllerQuestions extends \Hubzero\Component\SiteController
 			$row->set('reward', 1);
 		}
 
+		if (!JRequest::checkHoneypot())
+		{
+			$this->addComponentMessage(JText::_('JERROR_INVALID_HONEYPOT'), 'error');
+			$this->newTask($row);
+			return;
+		}
+
 		// Ensure the user added a tag
 		if (!$tags)
 		{
@@ -868,6 +880,11 @@ class AnswersControllerQuestions extends \Hubzero\Component\SiteController
 			return;
 		}
 
+		// We need to temporarily set this so the store() method
+		// has access to the tags string to be able to run it
+		// through spam checkers and validation.
+		$row->set('tags', $tags);
+
 		// Store new content
 		if (!$row->store(true))
 		{
@@ -923,7 +940,7 @@ class AnswersControllerQuestions extends \Hubzero\Component\SiteController
 						$toolname = preg_replace('/tool:/', '', $tag);
 						if (trim($toolname))
 						{
-							$rev = $objV->getCurrentVersionProperty ($toolname, 'revision');
+							$rev = $objV->getCurrentVersionProperty($toolname, 'revision');
 							$authors = $TA->getToolAuthors('', 0, $toolname, $rev);
 							if (count($authors) > 0)
 							{
@@ -1151,6 +1168,12 @@ class AnswersControllerQuestions extends \Hubzero\Component\SiteController
 		// Incoming
 		$response = JRequest::getVar('response', array(), 'post', 'none', 2);
 
+		// clean input
+		array_walk($response, function(&$field, $key)
+		{
+			$field = \Hubzero\Utility\Sanitize::clean($field);
+		});
+
 		// Initiate class and bind posted items to database fields
 		$row = new AnswersModelResponse($response['id']);
 		if (!$row->bind($response))
