@@ -276,7 +276,7 @@ class EventsControllerEvents extends \Hubzero\Component\SiteController
 
 	/**
 	 * Default Task
-	 * 
+	 *
 	 * @return [type] [description]
 	 */
 	public function displayTask()
@@ -647,7 +647,7 @@ class EventsControllerEvents extends \Hubzero\Component\SiteController
 		$row->load($id);
 
 		// Ensure we have an event
-		if (!$row)
+		if (!$row || !$row->id)
 		{
 			JError::raiseError(404, JText::_('EVENTS_CAL_LANG_NO_EVENTFOR') . ' ' . JText::_('EVENTS_CAL_LANG_THIS_DAY'));
 			return;
@@ -1226,8 +1226,13 @@ class EventsControllerEvents extends \Hubzero\Component\SiteController
 			$message = $eview->loadTemplate();
 			$message = str_replace("\n", "\r\n", $message);
 
-			// one for the event manager
-			$this->_sendEmail($hub, $email, $subject, $message);
+
+			// check to see if event manager email is configured
+			if ($email != "" || $email != NULL || !isset($email))
+			{
+			        // one for the event manager
+			        $this->_sendEmail($hub, $email, $subject, $message);
+			}
 
 			// one for the attendee
 			$this->_sendEmail($hub, $register['email'], $subject, $message);
@@ -1681,7 +1686,7 @@ class EventsControllerEvents extends \Hubzero\Component\SiteController
 			return;
 		}
 
-		$event->state = 2;
+		$event->state = 0;
 		$event->store();
 
 		// Delete the event
@@ -1743,6 +1748,10 @@ class EventsControllerEvents extends \Hubzero\Component\SiteController
 			return;
 		}
 
+		// good ol' form validation
+		JRequest::checkToken() or jexit('Invalid Token');
+		JRequest::checkHoneypot() or die('Invalid Field Data Detected. Please try again.');
+
 		$offset = $this->offset;
 
 		// Incoming
