@@ -21,60 +21,73 @@ if (!jq) {
 
 HUB.Groups = {
 	jQuery: jq,
-	
-	initialize: function() 
+
+	initialize: function()
 	{
 		// General Group Stuff
 		HUB.Groups.general();
-		
+
 		// Group Page Manager
 		HUB.Groups.pages();
 		HUB.Groups.modules();
 		HUB.Groups.categories();
 		HUB.Groups.pageVersions();
 	},
-	
+
 	general: function()
 	{
 		// group availablity checker
 		HUB.Groups.groupIdAvailability();
-		
+
 		// group menu alert fixer
 		HUB.Groups.groupMenuFix();
-		
+
 		// member ship notifications
 		HUB.Groups.membershipNotifications();
-		
+
 		// verify wanting to cancel from group
 		HUB.Groups.confirmCancelMembership();
-		
+
 		// logo picker to show logo picked in preview
 		HUB.Groups.customizePickLogo();
-		
+
 		// toggle between public and private group desc
 		HUB.Groups.togglePublicPrivateDescription();
-		
+
 		//scrolling asset browser
 		HUB.Groups.scrollingAssetBrowser();
-		
+
 		// add fancyselect to places
 		HUB.Groups.fancyselect();
+
+		// add confirmation for canceling
+		HUB.Groups.cancelMembership();
 	},
-	
+
 	//-----
-	
+
 	fancyselect: function()
 	{
 		var $ = this.jQuery;
-		
+
 		if ($('.fancy-select').length)
 		{
 			$('.fancy-select').HUBfancyselect();
 		}
 	},
-	
+
 	//-----
-	
+
+	cancelMembership: function()
+	{
+		var $ = this.jQuery;
+		$('.cancel').click(function(){
+			return confirm('Are you sure you want to leave this group?');
+		});
+	},
+
+	//-----
+
 	groupMenuFix: function()
 	{
 		var $ = this.jQuery;
@@ -83,7 +96,7 @@ HUB.Groups = {
 			var meta = $(this).find(".meta"),
 				metawidth = meta.outerWidth(true),
 				alrt = $(this).find(".alrt");
-			
+
 			if(alrt.length)
 			{
 				if(metawidth > 20)
@@ -94,34 +107,34 @@ HUB.Groups = {
 				{
 					alrt.css("right", 33-(20-metawidth));
 				}
-			} 
+			}
 		});
 	},
-	
+
 	//-----
-	
+
 	membershipNotifications: function()
 	{
 		var $ = this.jQuery;
-		
+
 		var content = "",
 			invites = $(".invites"),
 			requests = $(".requests");
-		
-		if(invites.length) 
+
+		if(invites.length)
 		{
 			invites.addClass("hide");
 			content += invites.html();
 		}
-		
-		if(requests.length) 
+
+		if(requests.length)
 		{
 			requests.addClass("hide");
 			content += requests.html();
 		}
-		
-		if(content != "") 
-		{	
+
+		if(content != "")
+		{
 			var timeout = setTimeout(function() {
 				$.fancybox({
 					autoSize:false,
@@ -139,25 +152,25 @@ HUB.Groups = {
 			}, 2000);
 		}
 	},
-	
+
 	//-----
-	
+
 	togglePublicPrivateDescription: function()
 	{
 		var $ = this.jQuery;
-		
+
 		var publicDesc = $("#public"),
 			privateDesc = $("#private"),
 			toggleSwitch = $("#toggle_description");
-			
-		
+
+
 		if(toggleSwitch.length)
 		{
 			toggleSwitch.removeClass('hide');
-			
+
 			toggleSwitch.bind("click", function(e) {
 				e.preventDefault();
-				
+
 				if(publicDesc.hasClass("hide"))
 				{
 					toggleSwitch.html('Show Private Description (-)');
@@ -166,52 +179,52 @@ HUB.Groups = {
 				{
 					toggleSwitch.html('Show Public Description (+)');
 				}
-				
+
 				publicDesc.toggleClass("hide");
 				privateDesc.toggleClass("hide");
 			});
 		}
 	},
-	
+
 	//-----
-	
+
 	confirmCancelMembership: function()
 	{
 		var $ = this.jQuery;
-		
+
 		$(".cancel_group_membership").live('click', function(e) {
 			e.preventDefault();
-			
+
 			var answer = confirm('Are you sure you would like to cancel your group membership?');
-			if(answer) 
-			{ 
+			if(answer)
+			{
 				window.location = this.href;
 			}
 		});
 	},
-	
+
 	//-----
-	
+
 	customizePickLogo: function()
 	{
 		var $ = this.jQuery;
-		
+
 		var logo = "",
 			logoSelecter = $("#group_logo");
-		
+
 		if(logoSelecter.length)
 		{
 			$('#group-logo-label').on("change", "#group_logo", function(e) {
-				
+
 				if(this.value == "")
 				{
 					logo = '<img src="/components/com_groups/assets/img/group_default_logo.png" />';
 				}
-				else 
+				else
 				{
 					logo = '<img src="'+this.value+'" />';
 				}
-				
+
 				$("#logo_picked").html(logo)
 			});
 		}
@@ -222,7 +235,7 @@ HUB.Groups = {
 	imagesUploaded: function()
 	{
 		var $ = this.jQuery;
-	
+
 		if ($("#group_logo").length)
 		{
 			var current = $("#group_logo").val();
@@ -234,13 +247,13 @@ HUB.Groups = {
 			});
 		}
 	},
-	
+
 	//-----
-	
+
 	scrollingAssetBrowser: function()
 	{
 		var $ = this.jQuery;
-		
+
 		// append floating iframe toggle button to floating iframe container
 		var floatingAssetBrowser = $('.floating-iframe-container');
 		if (floatingAssetBrowser.length)
@@ -257,32 +270,32 @@ HUB.Groups = {
 					$(this).toggleClass('opened');
 				});
 		}
-		
+
 		// initialize scolling asset browser
 		HUB.Groups._moveScrollingAssetBrowser();
 	},
-	
+
 	//-----
-	
+
 	_moveScrollingAssetBrowser: function()
 	{
 		var $ = this.jQuery;
-		
+
 		var floatingIframe = $('.floating-iframe'),
 			floatingIframeToggle = $('.floating-iframe-toggle');
-		
+
 		if (floatingIframe.length)
 		{
 			var scrollTop = $(document).scrollTop(),
 				min       = floatingIframe.parents('form').find('fieldset').first().offset().top,
 				max       = floatingIframe.parents('form').find('fieldset').last().offset().top + floatingIframe.parents('form').find('fieldset').last().outerHeight(true) - floatingIframe.outerHeight(true);
-			
+
 			if ( scrollTop > min && scrollTop < max)
 			{
 				floatingIframe.css({
 					top: scrollTop - min
 				});
-				
+
 				if (floatingIframeToggle.length)
 				{
 					floatingIframeToggle.css({
@@ -292,17 +305,17 @@ HUB.Groups = {
 			}
 		}
 	},
-	
+
 	//-----
-	
+
 	groupIdAvailability: function()
 	{
-		var $ = this.jQuery; 
+		var $ = this.jQuery;
 		$("#group_cn_field")
 			.on("keydown", function(event) {
 				$('.available, .not-available').remove();
 			})
-			.on("keyup", function(event) { 
+			.on("keyup", function(event) {
 				$.ajax({
 					url: 'index.php?option=com_groups&task=groupavailability&no_html=1',
 					data: { 'group' : $(this).val() },
@@ -331,25 +344,25 @@ HUB.Groups = {
 				});
 			});
 	},
-	
+
 	//-----
-	
+
 	pages: function()
 	{
 		var $ = this.jQuery;
-		
+
 		// Tabbed Interface
 		HUB.Groups.pagesTabs();
 
 		// fixed header
 		HUB.Groups.pageManagerFixedToolbar();
-		
+
 		// Reorder Pages
 		HUB.Groups.pagesReorderPages();
-		
+
 		// Page Preview
 		HUB.Groups.pagesPagePreview();
-		
+
 		// action changer
 		HUB.Groups.pagesEditPageActionChanger();
 
@@ -358,7 +371,7 @@ HUB.Groups = {
 
 		// page category
 		HUB.Groups.pagesEditPageCategory();
-		
+
 		// Page & module Search
 		$('.group-page-manager').on('keyup', '.toolbar .search input', function(event) {
 			var term = $(this).val(),
@@ -367,15 +380,15 @@ HUB.Groups = {
 			HUB.Groups.pagesFilterClear();
 			HUB.Groups.pagesSearchList(term, list);
 		});
-		
+
 		// Page & Module Filter
-		if ($('.toolbar .filter select').length) 
+		if ($('.toolbar .filter select').length)
 		{
 			$('.toolbar .filter select').HUBfancyselect({
 				onSelected: function(t, d) {
 					var filter = ($(this).attr('data-value')) ? $(this).attr('data-value') : '',
 						list = $(this).parents('fieldset').find('ul.item-list').first();
-					
+
 					// build filter
 					if (filter != '')
 					{
@@ -388,22 +401,22 @@ HUB.Groups = {
 							filter = 'position-' + filter;
 						}
 					}
-					
+
 					HUB.Groups.pagesSearchClear();
 					HUB.Groups.pagesFilterList(filter, list);
 				}
 			});
-			
+
 			var filter = HUB.Groups._getUrlParam('filter');
 			if (filter != null)
 			{
 				$('.toolbar .filter select').HUBfancyselect('selectValue', filter);
 			}
 		}
-		
+
 		// jquery case insensitve search
 		jQuery.expr[':'].caseInsensitiveContains = function(a,i,m) {
-			return (a.textContent || a.innerText || "").toUpperCase().indexOf(m[3].toUpperCase())>=0; 
+			return (a.textContent || a.innerText || "").toUpperCase().indexOf(m[3].toUpperCase())>=0;
 		};
 	},
 
@@ -428,7 +441,7 @@ HUB.Groups = {
 
 		// mark pinned after scroll distance
 		$(window).scroll(function()
-		{			
+		{
 			var scollpos = $(window).scrollTop();
 			if (scollpos > toolbartop)
 			{
@@ -449,7 +462,7 @@ HUB.Groups = {
 	},
 
 	//-----
-	
+
 	pagesEditPageActionChanger: function()
 	{
 		var $ = this.jQuery;
@@ -490,7 +503,7 @@ HUB.Groups = {
 				$('input[name="task"]').val('save');
 			}
 		});
-		
+
 		// prefill last choice
 		if (localStorage && localStorage.getItem('groups.pagemanager.action'))
 		{
@@ -539,11 +552,11 @@ HUB.Groups = {
 		else
 		{
 			$('.page-parent').HUBfancyselect();
-		}	
+		}
 	},
-	
+
 	//-----
-	
+
 	pagesEditPageCategory: function()
 	{
 		var $ = this.jQuery;
@@ -551,7 +564,7 @@ HUB.Groups = {
 		if ($('.page-category').length)
 		{
 			var currentCategory = $('.page-category').val();
-			
+
 			$('.page-category').HUBfancyselect({
 				onSelected: function(t, data)
 				{
@@ -566,14 +579,14 @@ HUB.Groups = {
 							afterShow: function() {
 								// instantiate color picker
 								HUB.Groups.categoriesColorPicker();
-								
+
 								// submit of category
 								$('form.editcategory').on('submit', function(event){
 									event.preventDefault();
-						
+
 									// get title value
 									var title = $(this).find('input[type=text]').first();
-						
+
 									// make sure we have title
 									if (title.val() == '')
 									{
@@ -581,13 +594,13 @@ HUB.Groups = {
 										title.focus();
 										return false;
 									}
-						
+
 									// set the category
 									newCategory = title.val();
-						
+
 									// submit form
 									$.post($(this).attr('action'),$(this).serialize(), function(data) {
-										$.fancybox.close();  
+										$.fancybox.close();
 									});
 								});
 
@@ -619,13 +632,13 @@ HUB.Groups = {
 			});
 		}
 	},
-	
+
 	//-----
-	
+
 	pagesSearchList: function(search, list)
 	{
 		var $ = this.jQuery;
-		
+
 		if (search)
 		{
 			$('.group-page-manager').addClass('searching');
@@ -633,7 +646,7 @@ HUB.Groups = {
 			list.addClass('filtered').find('.no-results').remove();
 			list.find('.item-title:not(:caseInsensitiveContains("'+search+'"))').parents('li').hide();
 			list.find('.item-title:caseInsensitiveContains("'+search+'")').parents('li').show();
-			
+
 			//add no results node
 			if (list.find('li:visible').length == 0)
 			{
@@ -648,25 +661,25 @@ HUB.Groups = {
 			list.removeClass('filtered').find('.no-results').remove();
 		}
 	},
-	
+
 	//-----
-	
+
 	pagesSearchClear: function()
 	{
 		var $ = this.jQuery;
-		
+
 		if ($('.toolbar:visible .filter select').val() != '')
 		{
 			$('.toolbar:visible .search input').val('');
 		}
 	},
-	
+
 	//-----
-	
+
 	pagesFilterList: function(filter, list)
 	{
 		var $ = this.jQuery;
-		
+
 		if (filter != '')
 		{
 			$('.group-page-manager').addClass('filtering');
@@ -674,7 +687,7 @@ HUB.Groups = {
 			list.addClass('filtered').find('.no-results').remove();
 			list.find('.item-container:not(.' + filter + ')').parents('li').hide();
 			list.find('.item-container.' + filter).parents('li').show();
-			
+
 			//add no results node
 			if (list.find('li:visible').length == 0)
 			{
@@ -689,21 +702,21 @@ HUB.Groups = {
 			list.find('li').show();
 		}
 	},
-	
+
 	//-----
-	
+
 	pagesFilterClear: function()
 	{
 		var $ = this.jQuery;
-		
+
 		if ($('.toolbar:visible .filter select').val() != '')
 		{
 			$('.toolbar:visible .filter select').HUBfancyselect('clear');
 		}
 	},
-	
+
 	//-----
-	
+
 	pagesTabs: function()
 	{
 		var $ = this.jQuery;
@@ -712,14 +725,14 @@ HUB.Groups = {
 		{
 			return;
 		}
-		
+
 		// show tabs & hide sections
 		$('.group-page-manager .tabs').show();
 		$('.group-page-manager form > fieldset').hide();
 
 		//get active tab
 		var activeTab = window.location.hash.replace('#', '');
-		
+
 		// make sure we have active tab and its valid
 		if (activeTab == '')
 		{
@@ -739,9 +752,9 @@ HUB.Groups = {
 		// trigger hash change
 		$(window).trigger('hashchange');
 	},
-	
+
 	//-----
-	
+
 	pagesReorderPages: function()
 	{
 		var $ = this.jQuery;
@@ -751,7 +764,7 @@ HUB.Groups = {
 		{
 			return;
 		}
-		
+
 		// nested sortable page manager
 		$('.group-page-manager .pages').nestedSortable({
             handle: '.item-mover',
@@ -804,7 +817,7 @@ HUB.Groups = {
 	pagesReorderPagesSave: function(showRebuilding)
 	{
 		// get new order
-		var sort = $('.group-page-manager .pages').nestedSortable('toArray', { 
+		var sort = $('.group-page-manager .pages').nestedSortable('toArray', {
 			excludeRoot: true,
 		});
 
@@ -847,22 +860,22 @@ HUB.Groups = {
 
 		$(window).off('beforeunload');
 	},
-	
+
 	//-----
-	
+
 	pagesPagePreview: function()
 	{
 		var $ = this.jQuery;
-		
+
 		// preview page lightbox
 		$('.item-list .page-preview').fancybox({
 			type: 'iframe',
 			width: 1024
 		});
 	},
-	
+
 	//-----
-	
+
 	pageVersions: function()
 	{
 		var $ = this.jQuery;
@@ -927,14 +940,14 @@ HUB.Groups = {
 	pageVersionMangerActions: function()
 	{
 		var $ = this.jQuery;
-		
+
 		// switch to source
 		$('.version-source').on('click', function(event){
 			event.preventDefault();
 			$(this).toggleClass('active');
 			$('.version-content').toggle();
 			$('.version-code').toggle();
-			
+
 			HUB.Groups.pageVersionMangerResize();
 		});
 
@@ -948,7 +961,7 @@ HUB.Groups = {
 	},
 
 	//-----
-	
+
 	pageVersionManagerFixedToolbar: function()
 	{
 		var $ = this.jQuery;
@@ -961,7 +974,7 @@ HUB.Groups = {
 		// fixed toolbar
 		var toolbartop = $('.toolbar').offset().top;
 		$('.toolbar').width($('.toolbar').width());
-		$(window).scroll(function() {			
+		$(window).scroll(function() {
 			var scollpos = $(window).scrollTop();
 			if (scollpos > toolbartop)
 			{
@@ -982,76 +995,76 @@ HUB.Groups = {
 	},
 
 	//-----
-	
+
 	modules: function()
 	{
 		var $ = this.jQuery;
-		
+
 		$('#field-assignment').on('change', function(event) {
 			event.preventDefault();
-			
+
 			//do we want on all pages
 			if ($(this).val() == '0')
 			{
 				$('fieldset.assignment').attr('disabled', 'disabled');
 				HUB.Groups.moduleMenuSelectAll();
-			} 
+			}
 			else
 			{
 				$('fieldset.assignment').removeAttr('disabled');
 			}
 		});
-		
+
 		$('#selectall').on('click', function(event){
 			event.preventDefault();
 			HUB.Groups.moduleMenuSelectAll();
 		});
-		
+
 		$('#clearselection').on('click', function(event){
 			event.preventDefault();
 			HUB.Groups.moduleMenuClearSelection();
 		});
 	},
-	
+
 	//-----
-	
+
 	moduleMenuSelectAll: function()
 	{
 		var $ = this.jQuery;
-		
+
 		$('fieldset.assignment').find('input[type=checkbox]:not(:checked)').attr('checked','checked');
 	},
-	
+
 	//-----
-	
+
 	moduleMenuClearSelection: function()
 	{
 		var $ = this.jQuery;
-		
+
 		$('fieldset.assignment').find('input[type=checkbox]:checked').removeAttr('checked');
 	},
-	
+
 	//-----
-	
+
 	categories: function()
 	{
 		HUB.Groups.categoriesColorPicker();
 	},
-	
+
 	//-----
-	
+
 	categoriesColorPicker: function()
 	{
 		var $ = this.jQuery;
-		
+
 		var categoryColorPicker = $('#field-category-color');
-		
+
 		if (categoryColorPicker.length)
 		{
 			// init color on input
 			var color = '#' + categoryColorPicker.val();
 			categoryColorPicker.css('border-color', color);
-			
+
 			// create color picker
 			categoryColorPicker.colpick({
 				layout: 'hex',
@@ -1063,9 +1076,9 @@ HUB.Groups = {
 			});
 		}
 	},
-	
+
 	//-----
-	
+
 	_getUrlParam: function( paramName )
 	{
 		var reParam = new RegExp( '(?:[\?&]|&)' + paramName + '=([^&]+)', 'i' ) ;
