@@ -384,6 +384,15 @@ class GroupsControllerGroups extends GroupsControllerAbstract
 	 */
 	public function newTask()
 	{
+		if (!$this->juser->authorise('core.create', $this->_option))
+		{
+			return $this->setRedirect(
+				JRoute::_('index.php?option=' . $this->_option),
+				JText::_('COM_GROUPS_ERROR_NOT_AUTH'),
+				'warning'
+			);
+		}
+
 		$this->editTask();
 	}
 
@@ -404,6 +413,15 @@ class GroupsControllerGroups extends GroupsControllerAbstract
 			return;
 		}
 
+		if (!$this->juser->authorise('core.edit', $this->_option))
+		{
+			return $this->setRedirect(
+				JRoute::_('index.php?option=' . $this->_option),
+				JText::_('COM_GROUPS_ERROR_NOT_AUTH'),
+				'warning'
+			);
+		}
+
 		//are we creating a new group?
 		if ($this->_task == 'new')
 		{
@@ -529,20 +547,40 @@ class GroupsControllerGroups extends GroupsControllerAbstract
 			return;
 		}
 
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		// Incoming
-		$g_gidNumber    	= JRequest::getInt('gidNumber', 0, 'post');
-		$g_cn           	= trim(JRequest::getVar('cn', '', 'post'));
-		$g_description  	= preg_replace('/\s+/', ' ',trim(JRequest::getVar('description', JText::_('NONE'), 'post')));
-		$g_discoverability	= JRequest::getInt('discoverability', 0, 'post');
-		$g_public_desc  	= trim(JRequest::getVar('public_desc',  '', 'post', 'none', 2));
-		$g_private_desc 	= trim(JRequest::getVar('private_desc', '', 'post', 'none', 2));
-		$g_restrict_msg 	= trim(JRequest::getVar('restrict_msg', '', 'post', 'none', 2));
-		$g_join_policy  	= JRequest::getInt('join_policy', 0, 'post');
-		$tags 				= trim(JRequest::getVar('tags', ''));
-		$lid 				= JRequest::getInt('lid', 0, 'post');
-		$customization      = JRequest::getVar('group', '', 'POST', 'none', 2);
-		$plugins            = JRequest::getVar('group_plugin', '', 'POST');
-		$params             = JRequest::getVar('params', array(), 'POST');
+		$g_gidNumber = JRequest::getInt('gidNumber', 0, 'post');
+		$c_gidNumber = JRequest::getVar('gidNumber', 0, 'post');
+
+		if ((string) $g_gidNumber !== (string) $c_gidNumber)
+		{
+			throw new Exception(JText::_('COM_GROUPS_ERROR_NO_ID'), 404);
+		}
+
+		if ((!$g_gidNumber && !$this->juser->authorise('core.create', $this->_option))
+		 || ($g_gidNumber && !$this->juser->authorise('core.edit', $this->_option)))
+		{
+			return $this->setRedirect(
+				JRoute::_('index.php?option=' . $this->_option),
+				JText::_('COM_GROUPS_ERROR_NOT_AUTH'),
+				'warning'
+			);
+		}
+
+		$g_cn              = trim(JRequest::getVar('cn', '', 'post'));
+		$g_description     = preg_replace('/\s+/', ' ',trim(JRequest::getVar('description', JText::_('NONE'), 'post')));
+		$g_discoverability = JRequest::getInt('discoverability', 0, 'post');
+		$g_public_desc     = \Hubzero\Utility\Sanitize::stripScripts(trim(JRequest::getVar('public_desc',  '', 'post', 'none', 2)));
+		$g_private_desc    = \Hubzero\Utility\Sanitize::stripScripts(trim(JRequest::getVar('private_desc', '', 'post', 'none', 2)));
+		$g_restrict_msg    = \Hubzero\Utility\Sanitize::stripScripts(trim(JRequest::getVar('restrict_msg', '', 'post', 'none', 2)));
+		$g_join_policy     = JRequest::getInt('join_policy', 0, 'post');
+		$tags              = trim(JRequest::getVar('tags', ''));
+		$lid               = JRequest::getInt('lid', 0, 'post');
+		$customization     = JRequest::getVar('group', '', 'POST', 'none', 2);
+		$plugins           = JRequest::getVar('group_plugin', '', 'POST');
+		$params            = JRequest::getVar('params', array(), 'POST');
 
 		$g_discussion_email_autosubscribe = JRequest::getInt('discussion_email_autosubscribe', 0, 'post');
 
@@ -605,6 +643,25 @@ class GroupsControllerGroups extends GroupsControllerAbstract
 			$plugin_access .= $plugin['name'] . '=' . $plugin['access'] . ',' . "\n";
 		}
 
+		// Run content through validation and spam filters
+		if (trim($g_public_desc))
+		{
+			JPluginHelper::importPlugin('content');
+			$results = JDispatcher::getInstance()->trigger('onContentBeforeSave', array(
+				'com_groups.group.description',
+				&$g_public_desc,
+				($this->_task == 'new')
+			));
+			foreach ($results as $result)
+			{
+				if ($result === false)
+				{
+					$this->setNotification(JText::_('COM_GROUPS_SAVE_ERROR_FAILED_VALIDATION'), 'error');
+					break;
+				}
+			}
+		}
+
 		// Push back into edit mode if any errors
 		if ($this->getNotifications())
 		{
