@@ -145,11 +145,6 @@ class MembersControllerRegister extends \Hubzero\Component\SiteController
 			$target_xprofile->set('homeDirectory', $hubHomeDir . '/' . $target_xprofile->get('username'));
 		}
 
-		if ($target_xprofile->get('jobsAllowed') == '')
-		{
-			$target_xprofile->set('jobsAllowed', 3);
-		}
-
 		if ($target_xprofile->get('regIP') == '')
 		{
 			$target_xprofile->set('regIP', JRequest::getVar('REMOTE_ADDR','','server'));
@@ -428,11 +423,6 @@ class MembersControllerRegister extends \Hubzero\Component\SiteController
 				$xprofile->set('homeDirectory', $hubHomeDir . '/' . $xprofile->get('username'));
 			}
 
-			if ($xprofile->get('jobsAllowed') == '')
-			{
-				$xprofile->set('jobsAllowed', 3);
-			}
-
 			if ($xprofile->get('regIP') == '')
 			{
 				$xprofile->set('regIP', JRequest::getVar('REMOTE_ADDR','','server'));
