@@ -246,6 +246,10 @@ class ResourcesControllerResources extends \Hubzero\Component\SiteController
 			'tag'    => trim(JRequest::getVar('tag', '', 'request', 'none', 2)),
 			'tag_ignored' => array()
 		);
+		if (!in_array($this->view->filters['sortby'], array('date', 'date_published', 'date_created', 'date_modified', 'title', 'rating', 'ranking', 'random')))
+		{
+			throw new Exception(JText::sprintf('Invalid sort value of "%s".', $this->view->filters['sortby']), 404);
+		}
 
 		if (isset($this->view->filters['tag']) && $this->view->filters['tag'] != '')
 		{
@@ -988,6 +992,11 @@ class ResourcesControllerResources extends \Hubzero\Component\SiteController
 		$parent = JRequest::getInt("id", "");
 		$child = JRequest::getVar("resid", "");
 
+		if (!$parent || !$child)
+		{
+			JError::raiseError(404, JText::_('COM_RESOURCES_RESOURCE_NOT_FOUND'));
+		}
+
 		//load resource
 		$activechild = new ResourcesResource($this->database);
 		$activechild->load($child);
@@ -1000,6 +1009,12 @@ class ResourcesControllerResources extends \Hubzero\Component\SiteController
 
 		//get manifest
 		$manifest = $this->getVideoManifestForResource( $activechild );
+
+		if (!file_exists(PATH_APP . $manifest))
+		{
+			JError::raiseError(404, JText::_('COM_RESOURCES_RESOURCE_NOT_FOUND'));
+		}
+
 		$manifest = json_decode( file_get_contents( JPATH_ROOT . $manifest ) );
 
 		//media tracking object
@@ -2133,7 +2148,8 @@ class ResourcesControllerResources extends \Hubzero\Component\SiteController
 		$resource->path = trim($resource->path);
 
 		// Ensure we have a path
-		if (empty($resource->path))
+		// Ensure the resource is published (stemedhub #472)
+		if ($resource->published != 1 || empty($resource->path))
 		{
 			JError::raiseError(404, JText::_('COM_RESOURCES_FILE_NOT_FOUND'));
 			return;
