@@ -36,6 +36,7 @@ include_once(JPATH_ROOT . DS . 'components' . DS . 'com_storefront' . DS . 'mode
 include_once(JPATH_ROOT . DS . 'components' . DS . 'com_storefront' . DS . 'models' . DS . 'CourseOffering.php');
 include_once(JPATH_ROOT . DS . 'components' . DS . 'com_storefront' . DS . 'models' . DS . 'Sku.php');
 include_once(JPATH_ROOT . DS . 'components' . DS . 'com_storefront' . DS . 'models' . DS . 'Coupon.php');
+include_once(JPATH_ROOT . DS . 'components' . DS . 'com_storefront' . DS . 'models' . DS . 'Collection.php');
 
 /**
  *
@@ -49,6 +50,9 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 	 */
 	var $lookupCollections = NULL;
 
+	// Access levels scope (what is allowed to display)
+	var $accessLevelsScope = false;
+
 	// Database instance
 	var $db = NULL;
 
@@ -66,7 +70,6 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		JFactory::getLanguage()->load('com_storefront');
 	}
 
-
 	/* ------------------------------------- Instance config functions ----------------------------------------------- */
 
 
@@ -92,38 +95,221 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		$this->lookupCollections[] = NULL;
 	}
 
+	/**
+	 * Add access level scope for entities having access property (currently products only)
+	 *
+	 * @param  array Access levels IDs
+	 * @return void
+	 */
+	public function addAccessLevels($accessLevels)
+	{
+		$this->accessLevelsScope = array_merge(array('NULL', 0), $accessLevels);
+	}
+
+
 
 	/* ------------------------------------- Main working functions ----------------------------------------------- */
 
+	/**
+	 * Get a collection
+	 *
+	 * @param	int							collection ID
+	 * @return	StorefrontModelCollection 	Instance of a collection
+	 */
+	public function getCollection($cId)
+	{
+		$collection = new StorefrontModelCollection();
+
+		// Get all product info
+		$collectionInfo = $this->getCollectionInfo($cId, true);
+
+		//print_r($collectionInfo); die;
+
+		$collection->setType($collectionInfo->cType);
+		$collection->setId($collectionInfo->cId);
+		$collection->setName($collectionInfo->cName);
+		$collection->setActiveStatus($collectionInfo->cActive);
+
+		$collection->verify();
+
+		return $collection;
+	}
 
 	/**
-	 * Get all non-empty (those that have at least one active product) root (no parents) product category collections
+	 * Get collection information
+	 *
+	 * @param	int			Collection ID
+	 * @param  	bool		Flag whether to show inactive collection info
+	 * @return 	object		Collection info
+	 */
+	public function getCollectionInfo($cId, $showInactive = false)
+	{
+		$sql = "SELECT * FROM `#__storefront_collections` c
+ 				WHERE c.`cId` = " . $this->_db->quote($cId);
+
+		if (!$showInactive)
+		{
+			$sql .= " AND `cActive` = 1";
+		}
+
+		$this->_db->setQuery($sql);
+		$collection = $this->_db->loadObject();
+
+		return $collection;
+	}
+
+
+	/**
+	 * Get all non-empty (those that have at least one active product) root (no parents) product 'category' collections
+	 *
+	 * @param  	string 	What to return (count or rows)
+	 * @param	array 	Filters
+	 * @return 	void
+	 */
+	public function getRootCategories($return = 'rows', $filters = false)
+	{
+		return $this->_getCollections('category', $filters);
+	}
+
+	/**
+	 * Get all root (no parents) product 'category' collections
 	 *
 	 * @param  void
 	 * @return void
 	 */
-	public function getRootCategories()
+	public function getCategories($rtrn='list', $filters = array())
 	{
-		return $this->_getCollections('category');
+		$filters['collectionType'] = 'category';
+		return $this->_getAllCollections($rtrn, $filters);
+	}
+
+	public function getCollections($rtrn='list', $filters = array())
+	{
+		return $this->_getAllCollections($rtrn, $filters);
 	}
 
 	/**
 	 * Check if collection exists
 	 *
-	 * @param  $c -- collection ID (+ alias in the future)
-	 * @return int cId on success, false if no match found
+	 * @param  	int		collection ID
+	 * @return 	int 	cId on success, null if no match found
 	 */
-	public function collectionExists($c)
+	public function collectionExists($cId, $showInactive = false)
 	{
-		$sql = "SELECT cId FROM `#__storefront_collections` c WHERE c.`cId` = " . $this->_db->quote($c) . " AND c.`cActive` = 1";
+		$sql = "SELECT `cId` FROM `#__storefront_collections` c WHERE c.`cId` = " . $this->_db->quote($cId);
+		if (!$showInactive)
+		{
+			$sql .= " AND c.`cActive` = 1";
+		}
 
 		$this->_db->setQuery($sql);
-		//echo $this->_db->_sql; die;
 		$cId = $this->_db->loadResult();
 
 		return $cId;
 	}
 
+	/**
+	 * Add collection
+	 *
+	 * @param	StorefrontModelCollection
+	 * @return	void
+	 */
+	public function addCollection($collection)
+	{
+		return $this->doCollection($collection, 'add');
+	}
+
+	/**
+	 * Update existing collection
+	 *
+	 * @param	StorefrontModelCollection
+	 * @return	void
+	 */
+	public function updateCollection($collection)
+	{
+		return $this->doCollection($collection, 'update');
+	}
+
+	/**
+	 * Handle collection actions (add, update)
+	 *
+	 * @param	StorefrontModelCollection
+	 * @param 	string
+	 * @return	string							category ID
+	 */
+	private function doCollection($collection, $action)
+	{
+		$allowedActions = array('add', 'update');
+
+		// Check everything
+		$cId = $collection->getId();
+
+		if (!in_array($action, $allowedActions))
+		{
+			throw new Exception(JText::_('Bad action. Why would you try to do something like that anyway?'));
+		}
+
+		if ($action == 'update')
+		{
+			// Check if the ID is set
+			if (empty($cId))
+			{
+				throw new Exception(JText::_('Cannot update collection: no collection ID set.'));
+			}
+
+			// check if category exists
+			if (!$this->collectionExists($cId, true))
+			{
+				throw new Exception(JText::_('Cannot update collection: collection does not exist.'));
+			}
+		}
+		elseif ($action == 'add')
+		{
+			if ($this->collectionExists($cId, true))
+			{
+				throw new Exception(JText::_('Cannot add collection: collection already exists.'));
+			}
+			elseif (empty($cId))
+			{
+				throw new Exception(JText::_('Cannot add collection: the new ID must be provided.'));
+			}
+		}
+
+		// ### Do the collection
+		if ($action == 'update')
+		{
+			$sql = "UPDATE `#__storefront_collections` SET ";
+		}
+		elseif ($action == 'add')
+		{
+			$sql = "INSERT INTO `#__storefront_collections` SET ";
+		}
+
+		$sql .= "
+				`cName` = " . $this->_db->quote($collection->getName()) . ",
+				`cActive` = " . $this->_db->quote($collection->getActiveStatus()) . ",
+				`cType` = " . $this->_db->quote($collection->getType());
+
+		// Set pId if needed if adding new product
+		if ($action == 'add' && !empty($cId))
+		{
+			$sql .= ",
+				`cId` = " . $this->_db->quote($collection->getId());
+		}
+
+		// Add WHERE if updating product
+		if ($action == 'update')
+		{
+			$sql .= " WHERE `cId` = " . $this->_db->quote($collection->getId());
+		}
+
+		$this->_db->setQuery($sql);
+		//print_r($this->_db->replacePrefix($this->_db->getQuery())); die;
+		$this->_db->query();
+
+		return ($cId);
+	}
+
 	/**
 	 * Check if product exists
 	 *
@@ -137,7 +323,8 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		{
 			$lookupField = 'pId';
 		}
-		else {
+		else
+		{
 			$lookupField = 'pAlias';
 		}
 
@@ -153,6 +340,60 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		return $pId;
 	}
 
+	/**
+	 * Check if product exists and can be viewed by the current user
+	 *
+	 * @param  	int		product ID or alias
+	 * @return 	int 	pId on success, null if no match found
+	 */
+	public function checkProduct($product, $showInactive = false)
+	{
+		// Integer is a pID, string must be an alias
+		if (is_numeric($product))
+		{
+			$lookupField = 'pId';
+		}
+		else
+		{
+			$lookupField = 'pAlias';
+		}
+
+		$sql = "SELECT `pId`, `access` FROM `#__storefront_products` p WHERE p.`{$lookupField}` = " . $this->_db->quote($product);
+		if (!$showInactive)
+		{
+			$sql .= " AND p.`pActive` = 1";
+		}
+
+		$this->_db->setQuery($sql);
+		$pInfo = $this->_db->loadObject();
+
+		$response = new stdClass();
+
+		$response->status = 1;
+		if (empty($pInfo))
+		{
+			$response->status = 0;
+			$response->errorCode = 404;
+			$response->message = 'COM_STOREFRONT_PRODUCT_NOT_FOUND';
+			return $response;
+		}
+
+		// Check if the product can be viewed (if access level scope is set)
+		if ($this->accessLevelsScope)
+		{
+			if (!in_array($pInfo->access, $this->accessLevelsScope))
+			{
+				$response->status = 0;
+				$response->errorCode = 403;
+				$response->message = 'COM_STOREFRONT_PRODUCT_ACCESS_NOT_AUTHORIZED';
+				return $response;
+			}
+		}
+
+		$response->pId = $pInfo->pId;
+		return $response;
+	}
+
 	/**
 	 * Check if coupon exists
 	 *
@@ -175,18 +416,78 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 	 * @param  void
 	 * @return void
 	 */
-	public function getProducts()
+	public function getProducts ($return = 'rows', $showOnlyActive = true, $filters = false)
 	{
-		$sql = "SELECT DISTINCT p.* FROM `#__storefront_products` p
-				JOIN `#__storefront_product_collections` c ON p.`pId` = c.`pId`";
-		$sql .= " WHERE p.`pActive` = 1";
+		$sql = "SELECT DISTINCT p.*, pt.ptName FROM `#__storefront_products` p
+				LEFT JOIN `#__storefront_product_types` pt ON p.`ptId` = pt.`ptId`
+				LEFT JOIN `#__storefront_product_collections` c ON p.`pId` = c.`pId`";
+		$sql .= " WHERE 1";
 
-		foreach	($this->lookupCollections as $cId)
+		if ($showOnlyActive)
 		{
-			$sql .= " AND c.`cId` = " . $this->_db->quote($cId);
+			$sql .= " AND `pActive` = 1";
+		}
+
+		// Filter by collections
+		if ($this->lookupCollections)
+		{
+			foreach ($this->lookupCollections as $cId)
+			{
+				$sql .= " AND c.`cId` = " . $this->_db->quote($cId);
+			}
+		}
+		// Filter by authorized view levels (if current user scope is set)
+		if ($this->accessLevelsScope)
+		{
+			$sql .= " AND (p.`access` IS NULL OR p.`access` IN(";
+			$accessLevels = '0';
+			foreach ($this->accessLevelsScope as $avl)
+			{
+				$accessLevels .= ', ' . $avl;
+			}
+			$sql .= $accessLevels;
+			$sql .= '))';
+		}
+		// Filter by filters
+		//print_r($filters);
+
+		if (isset($filters['sort']))
+		{
+
+			if ($filters['sort'] == 'title')
+			{
+				$filters['sort'] = 'pName';
+			}
+			if ($filters['sort'] == 'state')
+			{
+				$filters['sort'] = 'pActive';
+			}
+
+			$sql .= " ORDER BY " . $filters['sort'];
+
+			if (isset($filters['sort_Dir']))
+			{
+				$sql .= ' ' . $filters['sort_Dir'];
+			}
+		}
+
+		if (isset($filters['limit']) && is_numeric($filters['limit']))
+		{
+			$sql .= ' LIMIT ' . $filters['limit'];
+
+			if (isset($filters['start']) && is_numeric($filters['start']))
+			{
+				$sql .= ' OFFSET ' . $filters['start'];
+			}
 		}
 
 		$this->_db->setQuery($sql);
+		//print_r($this->_db->replacePrefix($this->_db->getQuery()));
+		$this->_db->execute();
+		if ($return == 'count')
+		{
+			return($this->_db->getNumRows());
+		}
 		$products = $this->_db->loadObjectList();
 
 		return $products;
@@ -201,7 +502,9 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 	 */
 	public function getProductInfo($pId, $showInactive = false)
 	{
-		$sql = "SELECT p.* FROM `#__storefront_products` p WHERE p.`pId` = {$pId}";
+		$sql = "SELECT p.*, pt.ptName, pt.ptModel FROM `#__storefront_products` p
+ 				LEFT JOIN `#__storefront_product_types` pt ON pt.ptId = p.ptId
+ 				WHERE p.`pId` = " . $this->_db->quote($pId);
 
 		if (!$showInactive)
 		{
@@ -209,11 +512,51 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		}
 
 		$this->_db->setQuery($sql);
+		//print_r($this->_db->replacePrefix($this->_db->getQuery())); die;
 		$product = $this->_db->loadObject();
 
 		return $product;
 	}
 
+	/**
+	 * Get product meta information
+	 * TODO Rewrite to use Product Class
+	 *
+	 * @param	int			Product ID
+	 * @param  	bool		Flag whether to show inactive product info
+	 * @return 	object		Product info
+	 */
+	public function getProductMeta($pId, $showInactive = false)
+	{
+		$sql = "SELECT pm.pmKey, pm.pmValue
+				FROM `#__storefront_product_meta` pm
+ 				LEFT JOIN `#__storefront_products` p ON pm.pId = p.pId
+ 				WHERE pm.`pId` = " . $this->_db->quote($pId);
+
+		if (!$showInactive)
+		{
+			$sql .= " AND p.`pActive` = 1";
+		}
+
+		$this->_db->setQuery($sql);
+		//print_r($this->_db->replacePrefix($this->_db->getQuery()));
+		$productMeta = $this->_db->loadObjectList('pmKey');
+
+		return $productMeta;
+	}
+
+	/**
+	 * Set product meta information
+	 *
+	 * @param	int			Product ID
+	 * @param  	bool		Flag whether to show inactive product info
+	 * @return 	object		Product info
+	 */
+	public function setProductMeta($pId, $meta)
+	{
+		StorefrontModelProduct::setMeta($pId, $meta);
+	}
+
 	/**
 	 * Get product option groups and options
 	 *
@@ -298,6 +641,102 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		return $ret;
 	}
 
+	// Get all option groups (for admin)
+	public function getOptionGroups($rtrn = 'list', $filters = array())
+	{
+		$sql = "SELECT og.*
+				FROM `#__storefront_option_groups` og
+				WHERE 1";
+
+		// Filter by filters
+		//print_r($filters);
+		if (isset($filters['active']) && $filters['active'] == 1)
+		{
+			$sql .= " AND ogActive = 1";
+		}
+
+		if (isset($filters['ids']) && !empty($filters['ids']))
+		{
+			if (!is_array($filters['ids']))
+			{
+				$filters['ids'] = array($filters['ids']);
+			}
+
+			$sql .= " AND ogId IN (0";
+			foreach ($filters['ids'] as $ogId)
+			{
+				$sql .= ', ' . $ogId;
+			}
+			$sql .= ")";
+		}
+
+		if (isset($filters['sort']))
+		{
+			$sql .= " ORDER BY " . $filters['sort'];
+
+			if (isset($filters['sort_Dir']))
+			{
+				$sql .= ' ' . $filters['sort_Dir'];
+			}
+		}
+		else {
+			$sql .= " ORDER BY ogName";
+		}
+
+		if (isset($filters['limit']) && is_numeric($filters['limit']))
+		{
+			$sql .= ' LIMIT ' . $filters['limit'];
+
+			if (isset($filters['start']) && is_numeric($filters['start']))
+			{
+				$sql .= ' OFFSET ' . $filters['start'];
+			}
+		}
+
+		$this->_db->setQuery($sql);
+		$this->_db->execute();
+		if ($rtrn == 'count')
+		{
+			return($this->_db->getNumRows());
+		}
+
+		//$res = $this->_db->loadObjectList('ogId');
+		$res = $this->_db->loadObjectList();
+		//print_r($res); die;
+
+		return $res;
+	}
+
+	/**
+	 * Get all options for the option group (for admin)
+	 *
+	 * @param	int			option group ID
+	 * @return	array 		options IDs
+	 */
+	public function getOptionGroupOptions($ogId, $return = 'rows', $showOnlyActive = true)
+	{
+		$sql = "SELECT * FROM `#__storefront_options` WHERE 1";
+		if ($showOnlyActive)
+		{
+			$sql .= " AND `oActive` = 1";
+		}
+		$sql .= " AND `ogId` = " . $this->_db->quote($ogId);
+		$this->_db->setQuery($sql);
+		//print_r($this->_db->replacePrefix($this->_db->getQuery()));
+
+		$this->_db->execute();
+		if ($return == 'count')
+		{
+			$res = $this->_db->getNumRows();
+		}
+		else
+		{
+			$res = $this->_db->loadObjectList();
+		}
+
+		return $res;
+	}
+
 	/**
 	 * Get SKU mapping to the provided options
 	 *
@@ -371,7 +810,7 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 	 * @param 	bool 		Flag whether to show inactive SKU and product info
 	 * @return 	array 		info
 	 */
-	public function getSkusInfo($skus, $showInactive = false)
+	public function getSkusInfo($skus, $showInactive = false, $filters = false)
 	{
 		$sqlIn = '(0';
 		foreach ($skus as $sId)
@@ -395,12 +834,47 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 				AND p.`pActive` = 1
 				AND s.`sActive` = 1 ";
 		}
-		$sql .= "
-				ORDER BY s.`sId`";
+
+		// Filter by filters
+		//print_r($filters);
+
+		if (isset($filters['sort']))
+		{
+
+			if ($filters['sort'] == 'title')
+			{
+				$filters['sort'] = 'sSku';
+			}
+			if ($filters['sort'] == 'state')
+			{
+				$filters['sort'] = 'sActive';
+			}
+
+			$sql .= " ORDER BY " . $filters['sort'];
+
+			if (isset($filters['sort_Dir']))
+			{
+				$sql .= ' ' . $filters['sort_Dir'];
+			}
+		}
+		else
+		{
+			$sql .= " ORDER BY s.`sId`";
+		}
+
+		if (isset($filters['limit']) && is_numeric($filters['limit']))
+		{
+			$sql .= ' LIMIT ' . $filters['limit'];
+
+			if (isset($filters['start']) && is_numeric($filters['start']))
+			{
+				$sql .= ' OFFSET ' . $filters['start'];
+			}
+		}
 
 		$this->_db->setQuery($sql);
+		//print_r($this->_db->replacePrefix($this->_db->getQuery())); die;
 		$this->_db->execute();
-		$found = $this->_db->getNumRows();
 
 		$rawSkusInfo = $this->_db->loadObjectList();
 
@@ -440,6 +914,12 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 				$skuMeta = array();
 			}
 
+			// Fix the NULL price
+			if ($row->sPrice == '')
+			{
+				$row->sPrice = 0;
+			}
+
 			if (!empty($row->oName))
 			{
 				$skuoptions[$row->oId] = $row->oName;
@@ -470,23 +950,64 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 	 * @param 	int 		SKU ID
 	 * @return 	array 		info
 	 */
-	public function getSkuInfo($sId)
+	public function getSkuInfo($sId , $showInactive = true)
 	{
-		$info = $this->getSkusInfo(array($sId), true);
-		return($info[$sId]);
+		$sInfo = $this->getSkusInfo(array($sId), $showInactive);
+		$sInfo = $sInfo[$sId];
+
+		//print_r($sInfo);die;
+
+		// Check if the product can be viewed (if access level scope is set)
+		if ($this->accessLevelsScope)
+		{
+			if (!in_array($sInfo['info']->access, $this->accessLevelsScope))
+			{
+				throw new Exception(JText::_('COM_STOREFRONT_PRODUCT_ACCESS_NOT_AUTHORIZED') . ': ' . $sInfo['info']->pName . ', ' . $sInfo['info']->oName);
+			}
+		}
+
+		return($sInfo);
 	}
 
 	/**
 	 * Get product SKU IDs
 	 *
 	 * @param	int			product id
-	 * @return	array 		collections
+	 * @return	array 		SKU IDs
 	 */
-	public function getProductSkus($pId)
+	public function getProductSkus($pId, $return = 'rows', $showOnlyActive = true)
 	{
-		$sql = "SELECT `sId` FROM `#__storefront_skus` WHERE `sActive` = 1 AND `pId` = " . $this->_db->quote($pId);
+		$sql = "SELECT";
+		if ($return == 'all')
+		{
+			$sql .= " *";
+		}
+		else
+		{
+			$sql .= " `sId`";
+		}
+		$sql .= " FROM `#__storefront_skus` WHERE 1";
+		if ($showOnlyActive)
+		{
+			$sql .= " AND `sActive` = 1";
+		}
+		$sql .= " AND `pId` = " . $this->_db->quote($pId);
 		$this->_db->setQuery($sql);
-		$res = $this->_db->loadResultArray();
+		//print_r($this->_db->replacePrefix($this->_db->getQuery()));
+
+		$this->_db->execute();
+		if ($return == 'count')
+		{
+			$res = $this->_db->getNumRows();
+		}
+		elseif ($return == 'all')
+		{
+			$res = $this->_db->loadObjectList();
+		}
+		else
+		{
+			$res = $this->_db->loadResultArray();
+		}
 
 		return $res;
 	}
@@ -524,6 +1045,21 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		$this->_db->query();
 	}
 
+	/**
+	 * Get product types
+	 *
+	 * @param	int					product type ID
+	 * @return	array 				info
+	 */
+	public function getProductTypes()
+	{
+		$sql = "SELECT * FROM `#__storefront_product_types`";
+
+		$this->_db->setQuery($sql);
+		$res = $this->_db->loadObjectList();
+		return $res;
+	}
+
 	/**
 	 * Get product type info
 	 *
@@ -551,6 +1087,12 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		return $course;
 	}
 
+	public function newProduct()
+	{
+		$product = new StorefrontModelProduct();
+		return $product;
+	}
+
 	/**
 	 * Get a product
 	 *
@@ -558,7 +1100,7 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 	 * @param	string						product type
 	 * @return	StorefrontModelProduct 	Instance of a product
 	 */
-	public function getProduct($pId, $productType = 'product')
+	public function getProduct($pId, $productType = 'product', $showOnlyActiveSkus = true)
 	{
 		$allowedProductTypes = array('product', 'course');
 
@@ -585,8 +1127,11 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		$product->setId($productInfo->pId);
 		$product->setName($productInfo->pName);
 		$product->setDescription($productInfo->pDescription);
+		$product->setFeatures($productInfo->pFeatures);
 		$product->setTagline($productInfo->pTagline);
 		$product->setActiveStatus($productInfo->pActive);
+		$product->setAccessLevel($productInfo->access);
+		$product->setAllowMultiple($productInfo->pAllowMultiple);
 
 		// Get collections
 		$collections = $this->_getProductCollections($pId);
@@ -596,7 +1141,7 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		}
 
 		// Get SKUs
-		$skus = $this->getProductSkus($pId);
+		$skus = $this->getProductSkus($pId, 'rows', $showOnlyActiveSkus);
 
 		// Add SKUs to product
 		foreach ($skus as $sId)
@@ -604,7 +1149,6 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 			$sku = $this->getSku($sId, $productType);
 			$product->addSku($sku);
 		}
-
 		$product->verify();
 
 		return $product;
@@ -631,6 +1175,18 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		return($this->_db->loadResult());
 	}
 
+	/**
+	 * Create and return a new SKU
+	 *
+	 * @param	void
+	 * @return	StorefrontModelSku 		Instance of a SKU
+	 */
+	public function newSku()
+	{
+		$sku = new StorefrontModelSku();
+		return $sku;
+	}
+
 	/**
 	 * Get a SKU
 	 *
@@ -653,6 +1209,8 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		//print_r($skuInfo); die;
 
 		$sku->setId($sId);
+		$sku->setProductId($skuInfo['info']->pId);
+		$sku->setName($skuInfo['info']->sSku);
 		$sku->setPrice($skuInfo['info']->sPrice);
 		$sku->setAllowMultiple($skuInfo['info']->sAllowMultiple);
 		$sku->setTrackInventory($skuInfo['info']->sTrackInventory);
@@ -693,7 +1251,7 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 	/**
 	 * Update existing product
 	 *
-	 * @param	StorefrontModelProduct 	Instance of a product to add
+	 * @param	StorefrontModelProduct 	Instance of a product to update
 	 * @return	int							product ID
 	 */
 	public function updateProduct($product)
@@ -798,7 +1356,10 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 				`pName` = " . $this->_db->quote($product->getName()) . ",
 				`pTagline` = " . $this->_db->quote($product->getTagline()) . ",
 				`pDescription` = " . $this->_db->quote($product->getDescription()) . ",
-				`pActive` = " . $product->getActiveStatus();
+				`pFeatures` = " . $this->_db->quote($product->getFeatures()) . ",
+				`pAllowMultiple` = " . $this->_db->quote($product->getAllowMultiple()) . ",
+				`pActive` = " . $this->_db->quote($product->getActiveStatus()) . ",
+				`access` = " . $this->_db->quote($product->getAccessLevel());
 
 
 		// Set pId if needed if adding new product
@@ -824,7 +1385,6 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 
 
 		// ### Do SKUs
-
 		$skus = $product->getSkus();
 
 		// Remember all sId used
@@ -832,93 +1392,8 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 
 		foreach ($skus as $sku)
 		{
-			// Get sId
-			$sId = $sku->getId();
-
-			// If no sID set -- this is a new SKU -- create a new record
-			if (empty($sId))
-			{
-				$sql = "INSERT INTO `#__storefront_skus` SET ";
-			}
-			// If sId is set -- update the existing SKU
-			else
-			{
-				$sql = "UPDATE `#__storefront_skus` SET ";
-			}
-
-			$sql .= "
-						`pId` = " . $this->_db->quote($pId) . ",
-						`sPrice` = " . $this->_db->quote($sku->getPrice()) . ",
-						`sAllowMultiple` = " . $sku->getAllowMultiple() . ",
-						`sTrackInventory` = " . $sku->getTrackInventory() . ",
-						`sInventory` = " . $sku->getInventoryLevel() . ",
-						`sEnumerable` = " . $sku->getEnumerable() . ",
-						`sActive` = " . $sku->getActiveStatus();
-
-			if (!empty($sId))
-			{
-				$sql .= " WHERE `sId` = " . $this->_db->quote($sId);
-			}
-
-			$this->_db->setQuery($sql);
-			//echo '<br>'; echo $this->_db->_sql;
-			$this->_db->query();
-			if (empty($sId))
-			{
-				$sId = $this->_db->insertid();
-			}
+			$sId = $this->saveSku($sku);
 			$activeSIds[] = $sId;
-
-			// Do SKU meta (if any)
-			$skuMeta = $sku->getMeta();
-
-			$activeMetaIds = array();
-
-			if (!empty($skuMeta))
-			{
-				// Go through each meta key and insert/update it, remembering the affected ID
-				foreach ($skuMeta as $k => $v)
-				{
-					$sql = "SET @skuMetaId := 0";
-					$this->_db->setQuery($sql);
-					$this->_db->query();
-					//echo '<br>'; echo $this->_db->_sql;
-
-					$sql = "INSERT INTO `#__storefront_sku_meta` SET
-							`sId` = " . $this->_db->quote($sId) . ",
-							`smKey` = " . $this->_db->quote($k) . ",
-							`smValue` = " . $this->_db->quote($v) . "
-							ON DUPLICATE KEY UPDATE
-							`smId` = (@skuMetaId := `smId`),
-							`sId` = " . $this->_db->quote($sId) . ",
-							`smKey` = " . $this->_db->quote($k) . ",
-							`smValue` = " . $this->_db->quote($v);
-
-					$this->_db->setQuery($sql);
-					$this->_db->query();
-					//echo '<br>'; echo $this->_db->_sql;
-
-					$sql = "SELECT IF(@skuMetaId = 0, LAST_INSERT_ID(), @skuMetaId)";
-					$this->_db->setQuery($sql);
-					$this->_db->query();
-					//echo '<br>'; echo $this->_db->_sql;
-
-					$activeMetaIds[] = $this->_db->loadResult();
-				}
-			}
-
-			// Delete unused Meta info: everything not affected above
-			$deleteSql = '(0';
-			foreach ($activeMetaIds as $metaId)
-			{
-				$deleteSql .= ", " . $this->_db->quote($metaId);
-			}
-			$deleteSql .= ')';
-
-			$sql = "DELETE FROM `#__storefront_sku_meta` WHERE `sId` = " . $this->_db->quote($sId) . " AND `smId` NOT IN {$deleteSql}";
-			$this->_db->setQuery($sql);
-			//echo '<br>'; echo $this->_db->_sql; die;
-			$this->_db->query();
 		}
 
 		// Delete unused SKUs
@@ -980,6 +1455,99 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		return $return;
 	}
 
+	public function saveSku($sku)
+	{
+		// Get sId
+		$sId = $sku->getId();
+
+		// If no sID set -- this is a new SKU -- create a new record
+		if (empty($sId))
+		{
+			$sql = "INSERT INTO `#__storefront_skus` SET ";
+		}
+		// If sId is set -- update the existing SKU
+		else
+		{
+			$sql = "UPDATE `#__storefront_skus` SET ";
+		}
+
+		$sql .= "
+						`pId` = " . $sku->getProductId() . ",
+						`sSku` = " . $this->_db->quote($sku->getName()) . ",
+						`sPrice` = " . $this->_db->quote($sku->getPrice()) . ",
+						`sAllowMultiple` = " . $sku->getAllowMultiple() . ",
+						`sTrackInventory` = " . $sku->getTrackInventory() . ",
+						`sInventory` = " . $sku->getInventoryLevel() . ",
+						`sEnumerable` = " . $sku->getEnumerable() . ",
+						`sActive` = " . $sku->getActiveStatus();
+
+		if (!empty($sId))
+		{
+			$sql .= " WHERE `sId` = " . $this->_db->quote($sId);
+		}
+
+		$this->_db->setQuery($sql);
+		//print_r($this->_db->replacePrefix($this->_db->getQuery()));
+		$this->_db->query();
+		if (empty($sId))
+		{
+			$sId = $this->_db->insertid();
+		}
+
+		// Do SKU meta (if any)
+		$skuMeta = $sku->getMeta();
+
+		$activeMetaIds = array();
+
+		if (!empty($skuMeta))
+		{
+			// Go through each meta key and insert/update it, remembering the affected ID
+			foreach ($skuMeta as $k => $v)
+			{
+				$sql = "SET @skuMetaId := 0";
+				$this->_db->setQuery($sql);
+				$this->_db->query();
+				//print_r($this->_db->replacePrefix($this->_db->getQuery())); die;
+
+				$sql = "INSERT INTO `#__storefront_sku_meta` SET
+							`sId` = " . $this->_db->quote($sId) . ",
+							`smKey` = " . $this->_db->quote($k) . ",
+							`smValue` = " . $this->_db->quote($v) . "
+							ON DUPLICATE KEY UPDATE
+							`smId` = (@skuMetaId := `smId`),
+							`sId` = " . $this->_db->quote($sId) . ",
+							`smKey` = " . $this->_db->quote($k) . ",
+							`smValue` = " . $this->_db->quote($v);
+
+				$this->_db->setQuery($sql);
+				$this->_db->query();
+				//print_r($this->_db->replacePrefix($this->_db->getQuery())); die;
+
+				$sql = "SELECT IF(@skuMetaId = 0, LAST_INSERT_ID(), @skuMetaId)";
+				$this->_db->setQuery($sql);
+				$this->_db->query();
+				//print_r($this->_db->replacePrefix($this->_db->getQuery())); die;
+
+				$activeMetaIds[] = $this->_db->loadResult();
+			}
+		}
+
+		// Delete unused Meta info: everything not affected above
+		$deleteSql = '(0';
+		foreach ($activeMetaIds as $metaId)
+		{
+			$deleteSql .= ", " . $this->_db->quote($metaId);
+		}
+		$deleteSql .= ')';
+
+		$sql = "DELETE FROM `#__storefront_sku_meta` WHERE `sId` = " . $this->_db->quote($sId) . " AND `smId` NOT IN {$deleteSql}";
+		$this->_db->setQuery($sql);
+		//print_r($this->_db->replacePrefix($this->_db->getQuery())); die;
+		$this->_db->query();
+
+		return $sId;
+	}
+
 	/**
 	 * Get coupon
 	 *
@@ -1249,7 +1817,7 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 	 * @param  $collectionType -- type of collection, category by default
 	 * @return void
 	 */
-	private function _getCollections($collectionType = 'category')
+	private function _getCollections($collectionType = 'category', $filters = false)
 	{
 		$sql = "SELECT DISTINCT c.`cId`, c.`cName`
 				FROM `#__storefront_collections` c
@@ -1260,8 +1828,78 @@ class StorefrontModelWarehouse extends \Hubzero\Base\Object
 		$sql .= " AND c.`cType` = '{$collectionType}'";
 
 		$this->_db->setQuery($sql);
-		//echo $this->_db->_sql;
 		$res = $this->_db->loadObjectList();
+		//print_r($this->_db->replacePrefix($this->_db->getQuery()));
+
+		return $res;
+	}
+
+	/**
+	 * Get all including empty root (no parents) collections
+	 * TODO: implement subcategories
+	 *
+	 * @param  $collectionType -- type of collection, category by default
+	 * @return void
+	 */
+	private function _getAllCollections($return = 'list', $filters = array())
+	{
+		$sql = "SELECT c.*
+				FROM `#__storefront_collections` c
+				WHERE c.`cParent` IS NULL";
+
+		// Filter by filters
+		//print_r($filters);
+		if (isset($filters['collectionType']))
+		{
+			$sql .= " AND c.`cType` = '{$filters['collectionType']}'";
+		}
+
+		if (isset($filters['active']))
+		{
+			$sql .= " AND cActive = 1";
+		}
+
+		if (isset($filters['sort']))
+		{
+			if ($filters['sort'] == 'title')
+			{
+				$filters['sort'] = 'cName';
+			}
+			if ($filters['sort'] == 'state')
+			{
+				$filters['sort'] = 'cActive';
+			}
+
+			$sql .= " ORDER BY " . $filters['sort'];
+
+			if (isset($filters['sort_Dir']))
+			{
+				$sql .= ' ' . $filters['sort_Dir'];
+			}
+		}
+		else {
+			$sql .= " ORDER BY cType";
+		}
+
+		if (isset($filters['limit']) && is_numeric($filters['limit']))
+		{
+			$sql .= ' LIMIT ' . $filters['limit'];
+
+			if (isset($filters['start']) && is_numeric($filters['start']))
+			{
+				$sql .= ' OFFSET ' . $filters['start'];
+			}
+		}
+
+		$this->_db->setQuery($sql);
+		$this->_db->execute();
+		if ($return == 'count')
+		{
+			return($this->_db->getNumRows());
+		}
+
+		$res = $this->_db->loadObjectList();
+		//print_r($this->_db->replacePrefix($this->_db->getQuery()));
 
 		return $res;
 	}
