@@ -148,6 +148,13 @@ class Module extends Object
 			$module = $this->module->module;
 		}
 
+		if (substr($stylesheet, 0, strlen('http')) == 'http'
+		 || substr($stylesheet, 0, strlen('://')) == '://')
+		{
+			\JFactory::getDocument()->addStylesheet($stylesheet);
+			return $this;
+		}
+
 		if ($module === true || strstr($stylesheet, '{') || strstr($stylesheet, '@'))
 		{
 			\JFactory::getDocument()->addStyleDeclaration($stylesheet);
@@ -196,6 +203,13 @@ class Module extends Object
 			$module = $this->module->module;
 		}
 
+		if (substr($script, 0, strlen('http')) == 'http'
+		 || substr($script, 0, strlen('://')) == '://')
+		{
+			\JFactory::getDocument()->addScript($script);
+			return $this;
+		}
+
 		if ($module === true || strstr($script, '(') || strstr($script, ';'))
 		{
 			\JFactory::getDocument()->addScriptDeclaration($script);
