@@ -282,13 +282,14 @@ class JSession extends JObject
 	 *
 	 * Use in conjunction with JHtml::_('form.token') or JSession::getFormToken.
 	 *
-	 * @param   string  $method  The request method in which to look for the token key.
+	 * @param   string   $method   The request method in which to look for the token key.
+	 * @param   boolean  $capture  Return result instead of throwing exception?
 	 *
 	 * @return  boolean  True if found and valid, false otherwise.
 	 *
 	 * @since   12.1
 	 */
-	public static function checkToken($method = 'post')
+	public static function checkToken($method = 'post', $capture = false)
 	{
 		if ($method == 'default')
 		{
@@ -296,11 +297,26 @@ class JSession extends JObject
 			return false;
 		}
 
+		$result = false;
+
+		if (is_string($method) && strstr($method, ','))
+		{
+			$method = explode(',', $method);
+			$method = array_map('trim', $method);
+		}
+		$method = (array) $method;
+
 		$token = self::getFormToken();
 		$app = JFactory::getApplication();
 
-		if (!JRequest::getVar($token, '', $method, 'alnum'))
+		foreach ($method as $m)
 		{
+			if (JRequest::getVar($token, '', $m, 'alnum'))
+			{
+				$result = true;
+				break;
+			}
+
 			$session = JFactory::getSession();
 			if ($session->isNew())
 			{
@@ -308,15 +324,20 @@ class JSession extends JObject
 				$app->redirect(JRoute::_('index.php'), JText::_('JLIB_ENVIRONMENT_SESSION_EXPIRED'));
 				$app->close();
 			}
-			else
-			{
-				return false;
-			}
 		}
-		else
+
+		if (!$result)
 		{
-			return true;
+			if ($capture)
+			{
+				return $result;
+			}
+
+			//throw new Exception(JText::_('JINVALID_TOKEN'), 403);
+			JError::raiseError(403, JText::_('JINVALID_TOKEN'));
 		}
+
+		return $result;
 	}
 
 	/**
@@ -915,27 +936,42 @@ class JSession extends JObject
 			}
 		}
 
+		// Record proxy forwarded for in the session in case we need it later
+		if (isset($_SERVER['HTTP_X_FORWARDED_FOR']))
+		{
+			$this->set('session.client.forwarded', $_SERVER['HTTP_X_FORWARDED_FOR']);
+		}
+
 		// Check for client address
-		if(in_array('fix_adress', $this->_security) && isset($_SERVER['REMOTE_ADDR']) && filter_var($_SERVER['REMOTE_ADDR'], FILTER_VALIDATE_IP) !== false)
+		if (in_array('fix_adress', $this->_security) && isset($_SERVER['REMOTE_ADDR']))
 		{
 			$ip = $this->get('session.client.address');
 
-			if($ip === null)
+			if ($ip === null)
 			{
 				$this->set('session.client.address', $_SERVER['REMOTE_ADDR']);
 			}
-			elseif($_SERVER['REMOTE_ADDR'] !== $ip)
+			elseif ($_SERVER['REMOTE_ADDR'] !== $ip)
 			{
 				$this->_state = 'error';
-
 				return false;
 			}
 		}
 
-		// Record proxy forwarded for in the session in case we need it later
-		if(isset($_SERVER['HTTP_X_FORWARDED_FOR']) && filter_var($_SERVER['HTTP_X_FORWARDED_FOR'], FILTER_VALIDATE_IP) !== false)
+		// Check for clients browser
+		if (in_array('fix_browser', $this->_security) && isset($_SERVER['HTTP_USER_AGENT']))
 		{
-			$this->set('session.client.forwarded', $_SERVER['HTTP_X_FORWARDED_FOR']);
+			$browser = $this->get('session.client.browser');
+
+			if ($browser === null)
+			{
+				$this->set('session.client.browser', $_SERVER['HTTP_USER_AGENT']);
+			}
+			elseif ($_SERVER['HTTP_USER_AGENT'] !== $browser)
+			{
+				// @todo remove code: 				$this->_state	=	'error';
+				// @todo remove code: 				return false;
+			}
 		}
 
 		return true;
