@@ -1,26 +1,28 @@
 <?php
 
+use Hubzero\Content\Migration\Base;
+
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
 /**
  * Migration script for adding pages plugin entry
  **/
-class Migration20130423204702PlgCoursesPages extends Hubzero_Migration
+class Migration20130423204702PlgCoursesPages extends Base
 {
 	/**
 	 * Up
 	 **/
-	protected static function up($db)
+	public function up()
 	{
-		self::addPluginEntry('courses', 'pages');
+		$this->addPluginEntry('courses', 'pages');
 	}
 
 	/**
 	 * Down
 	 **/
-	protected function down($db)
+	public function down()
 	{
-		self::deletePluginEntry('courses', 'pages');
+		$this->deletePluginEntry('courses', 'pages');
 	}
 }
\ No newline at end of file
