@@ -45,8 +45,7 @@ class plgContentEmailcloak extends JPlugin
 	 * @return	string	A regular expression that matches a link containing the parameters.
 	 */
 	protected function _getPattern ($link, $text) {
-		$pattern = '~(?:<a ([\w "\'=\@\.\-:;]*)href\s*=\s*"mailto:'
-			. $link . '"([\w "\'=\@\.\-:;]*))>' . $text . '</a>~i';
+		$pattern = '~(?:<a ([^>]*)href\s*=\s*"mailto:' . $link . '"([^>]*))>' . $text . '</a>~i';
 		return $pattern;
 	}
 
