@@ -474,10 +474,15 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 			'state'      => 1,
 			'access'     => 0
 		);
-		if (!$this->juser->get('guest'))
-		{
-			$this->view->filters['access'] = array(0, 1, 3);
-		}
+
+		/*
+		 * See ticket Qubes #311
+		 * Kevin Wojkovich - 8/12/2015
+		 */
+		//if (!$this->juser->get('guest'))
+		//{
+		//	$this->view->filters['access'] = array(0, 1, 3);
+		//}
 		if (in_array($this->juser->get('id'), $this->members))
 		{
 			$this->view->filters['access'] = array(0, 1, 3, 4);
@@ -485,7 +490,7 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 
 		$this->view->edit = JRequest::getVar('section', '');
 
-		$this->view->sections = $this->model->sections('list', array('state' => 1));
+		$this->view->sections = $this->model->sections('list', $this->view->filters);
 
 		$this->view->model = $this->model;
 
@@ -797,6 +802,7 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 			'state'      => 1,
 			'access'     => 0
 		);
+
 		if (!$this->juser->get('guest'))
 		{
 			$this->view->filters['access'] = array(0, 1, 3);
@@ -970,7 +976,7 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 		}
 
 		//check for alias duplicates within section?
-		if ($model->uniqueAliasCheck())
+		if ($model->uniqueAliasCheck($model->get('id')))
 		{
 			$this->addPluginMessage($model->getError(), 'error');
 			return $this->editcategory($model);
@@ -1248,9 +1254,12 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 			$this->view->post->set('scope', $this->model->get('scope'));
 			$this->view->post->set('created_by', $this->juser->get('id'));
 		}
-		elseif ($this->view->post->get('created_by') != $this->juser->get('id') && !$this->params->get('access-edit-thread'))
+		// - IMPORTANT - ONLY the original commenter can change the content.
+		// Group Managers can only delete OR report for abuse.
+		elseif ($this->view->post->get('created_by') != $this->juser->get('id') || !$this->params->get('access-edit-thread'))
 		{
-			$this->setRedirect(JRoute::_($this->base . '&scope=' . $section . '/' . $category));
+			$this->setRedirect(JRoute::_($this->base . '&scope=' . $sectionAlias . '/' . $category),
+				JText::_('PLG_GROUPS_FORUM_NOT_AUTHORIZED'), 'error');
 			return;
 		}
 
@@ -1377,24 +1386,22 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 
 		// Determine post save message
 		// Also, get subject of post for outgoing email, either the title of parent post (for replies), or title of current post (for new threads)
-		if (!$fields['id'])
+		if (!$fields['parent'])
 		{
-			if (!$fields['parent'])
-			{
-				$message = JText::_('PLG_GROUPS_FORUM_THREAD_STARTED');
-				$posttitle = $model->title;
-			}
-			else
-			{
-				$message = JText::_('PLG_GROUPS_FORUM_POST_ADDED');
-
-				/* @var $parentForumTablePost ForumTablePost */
-				$parentForumTablePost = new ForumTablePost($this->database);
-				$parentForumTablePost->load(intval($fields['parent']));
-				$posttitle = $parentForumTablePost->title;
-			}
+			$message = JText::_('PLG_GROUPS_FORUM_THREAD_STARTED');
+			$posttitle = $model->title;
 		}
 		else
+		{
+			$message = JText::_('PLG_GROUPS_FORUM_POST_ADDED');
+
+			/* @var $parentForumTablePost ForumTablePost */
+			$parentForumTablePost = new ForumTablePost($this->database);
+			$parentForumTablePost->load(intval($fields['parent']));
+			$posttitle = $parentForumTablePost->title;
+		}
+
+		if ($fields['id'])
 		{
 			$message = ($model->modified_by) ? JText::_('PLG_GROUPS_FORUM_POST_EDITED') : JText::_('PLG_GROUPS_FORUM_POST_ADDED');
 		}
@@ -1993,6 +2000,9 @@ class plgGroupsForum extends \Hubzero\Plugin\Plugin
 			return $this->sections();
 		}
 
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		$settings = JRequest::getVar('settings', array(), 'post');
 
 		$row = new \Hubzero\Plugin\Params($this->database);
