@@ -1111,6 +1111,11 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 		// Incoming
 		$fields = JRequest::getVar('fields', array(), 'post', 'none', 2);
 
+		if ($fields['id'] && !is_numeric($fields['id']))
+		{
+			JError::raiseError(404, JText::_('Post does not exist'));
+		}
+
 		// Get model
 		$row = new CollectionsModelItem($fields['id']);
 
@@ -1301,7 +1306,8 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 		}
 
 		// Display the main listing
-		return $this->_browse();
+		$app = JFactory::getApplication();
+		$app->redirect($this->member->getLink() . '&active=' . $this->_name);
 	}
 
 	/**
@@ -1424,7 +1430,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 		$collection = $this->model->collection($post->get('collection_id'));
 
 		// Did they confirm delete?
-		if (!$process || !$confirmdel || !JRequest::checkToken())
+		if (!$process || !$confirmdel)
 		{
 			if ($process && !$confirmdel)
 			{
@@ -1464,6 +1470,8 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 			return $view->loadTemplate();
 		}
 
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		$msg = JText::_('Post deleted.');
 		$type = 'passed';
 
@@ -1685,6 +1693,9 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 	 */
 	private function _savecollection()
 	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		// Login check
 		if ($this->juser->get('guest'))
 		{
@@ -1700,6 +1711,7 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 
 		// Incoming
 		$fields = JRequest::getVar('fields', array(), 'post', 'none', 2);
+		$fields['id'] = intval($fields['id']);
 
 		// Bind new content
 		$row = new CollectionsModelCollection();
@@ -1796,6 +1808,8 @@ class plgMembersCollections extends \Hubzero\Plugin\Plugin
 			return $view->loadTemplate();
 		}
 
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		// Mark the entry as deleted
 		$collection->set('state', 2);
 		if (!$collection->store())
