@@ -498,7 +498,7 @@ class plgMembersResume extends \Hubzero\Plugin\Plugin
 		}
 
 		// Check for request forgeries
-		JRequest::checkToken('get') or JRequest::checkToken() or jexit('Invalid Token');
+		JRequest::checkToken(array('get', 'post')) or jexit('Invalid Token');
 
 		// Incoming file
 		$file = JRequest::getVar('uploadres', '', 'files', 'array');
