@@ -380,7 +380,7 @@ class PlgResourcesReviewsHelper extends \Hubzero\Base\Object
 		}
 
 		// Perform some text cleaning, etc.
-		$row->content    = \Hubzero\Utility\Sanitize::clean($row->content);
+		$row->content    = \Hubzero\Utility\Sanitize::stripImages(\Hubzero\Utility\Sanitize::clean($row->content));
 		//$row->content    = nl2br($row->content);
 		$row->anonymous  = ($row->anonymous == 1 || $row->anonymous == '1') ? $row->anonymous : 0;
 		$row->created    = ($row->id ? $row->created : JFactory::getDate()->toSql());
@@ -434,7 +434,7 @@ class PlgResourcesReviewsHelper extends \Hubzero\Base\Object
 		$reply->load($replyid);
 
 		// Permissions check
-		if ($reply->created_by != JFactory::getUser()->get('id'))
+		if ($reply->created_by != JFactory::getUser()->get('id') && !JFactory::getUser()->authorise('admin_delete_reply', 'core.admin'))
 		{
 			return;
 		}
@@ -575,6 +575,7 @@ class PlgResourcesReviewsHelper extends \Hubzero\Base\Object
 			$review->tags = ($RE->tagsForEditing) ? $RE->tagsForEditing : '';
 		}
 		$review->rating = ($myr) ? $myr : $review->rating;
+		$review->state = 1;
 
 		// Store the object in our registry
 		$this->myreview = $review;
@@ -588,6 +589,9 @@ class PlgResourcesReviewsHelper extends \Hubzero\Base\Object
 	 */
 	public function savereview()
 	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		// Incoming
 		$resource_id = JRequest::getInt('resource_id', 0);
 
@@ -615,7 +619,7 @@ class PlgResourcesReviewsHelper extends \Hubzero\Base\Object
 		{
 			$row->state = 1;
 		}
-		$row->comment   = \Hubzero\Utility\Sanitize::clean($row->comment);
+		$row->comment   = \Hubzero\Utility\Sanitize::stripImages(\Hubzero\Utility\Sanitize::clean($row->comment));
 		$row->anonymous = ($row->anonymous == 1 || $row->anonymous == '1') ? $row->anonymous : 0;
 		$row->created   = ($row->created && $row->created != '0000-00-00 00:00:00') ? $row->created : JFactory::getDate()->toSql();
 
@@ -716,7 +720,7 @@ class PlgResourcesReviewsHelper extends \Hubzero\Base\Object
 		$review->load($reviewid);
 
 		// Permissions check
-		if ($review->user_id != JFactory::getUser()->get('id'))
+		if ($review->user_id != JFactory::getUser()->get('id') && !JFactory::getUser()->authorise("admin_delete_comment", "core.admin"))
 		{
 			return;
 		}
